@@ -1,4 +1,5 @@
-from typing import Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
+from urllib.parse import urlencode
 
 from openapi_schema_pydantic import (
     Contact,
@@ -15,8 +16,11 @@ from openapi_schema_pydantic import (
 from pydantic import AnyUrl, BaseModel, DirectoryPath, constr
 from typing_extensions import Type
 
+from starlite.cache import CacheBackendProtocol, SimpleCacheBackend
+from starlite.connection import Request
 from starlite.openapi.controller import OpenAPIController
 from starlite.template import TemplateEngineProtocol
+from starlite.types import CacheKeyBuilder
 
 
 class CORSConfig(BaseModel):
@@ -80,3 +84,21 @@ class TemplateConfig(BaseModel):
 
     directory: Union[DirectoryPath, List[DirectoryPath]]
     engine: Type[TemplateEngineProtocol]
+
+
+def default_cache_key_builder(request: Request) -> str:
+    """
+    Given a request object, returns a cache key by combining the path with the sorted query params
+    """
+    qp: List[Tuple[str, Any]] = list(request.query_params.items())
+    qp.sort(key=lambda x: x[0])
+    return request.url.path + urlencode(qp, doseq=True)
+
+
+class CacheConfig(BaseModel):
+    class Config:
+        arbitrary_types_allowed = True
+
+    backend: CacheBackendProtocol = SimpleCacheBackend()
+    expiration: int = 60  # value in seconds
+    cache_key_builder: CacheKeyBuilder = default_cache_key_builder
